package org.randombits.confluence.metadata.impl.handler;

import com.atlassian.confluence.core.ContentEntityManager;
import com.atlassian.confluence.core.ContentEntityObject;
import com.atlassian.confluence.pages.Attachment;
import com.atlassian.confluence.pages.AttachmentManager;
import org.randombits.confluence.metadata.AbstractTypeHandler;
import org.randombits.confluence.metadata.reference.AttachmentReference;
import org.springframework.beans.factory.annotation.Qualifier;

/**
 * Handles Attachments.
 */
public class AttachmentHandler extends AbstractTypeHandler<Attachment, AttachmentReference> {

    public static final String LEGACY_ALIAS = "AttachmentOption";

    public static final String ALIAS = "AttachmentReference";

    private final AttachmentManager attachmentManager;

    private final ContentEntityManager contentEntityManager;

    public AttachmentHandler( AttachmentManager attachmentManager, @Qualifier("contentEntityManager") ContentEntityManager contentEntityManager ) {
        super( Attachment.class, AttachmentReference.class );
        this.attachmentManager = attachmentManager;
        this.contentEntityManager = contentEntityManager;
    }

    @Override
    protected Attachment doGetOriginal( AttachmentReference stored ) {
        ContentEntityObject content = contentEntityManager.getById( stored.getContentId() );
        if ( content != null )
            return attachmentManager.getAttachment( content, stored.getFileName() );
        return null;
    }

    @Override
    protected AttachmentReference doGetStored( Attachment original ) {
        return new AttachmentReference( original );
    }

    @Override
    protected String getAlias() {
        return ALIAS;
    }
}
